@@ -1,32 +1,6 @@
-/*
-  Copyright 2008 Larry Gritz and the other authors and contributors.
-  All Rights Reserved.
-
-  Redistribution and use in source and binary forms, with or without
-  modification, are permitted provided that the following conditions are
-  met:
-  * Redistributions of source code must retain the above copyright
-    notice, this list of conditions and the following disclaimer.
-  * Redistributions in binary form must reproduce the above copyright
-    notice, this list of conditions and the following disclaimer in the
-    documentation and/or other materials provided with the distribution.
-  * Neither the name of the software's owners nor the names of its
-    contributors may be used to endorse or promote products derived from
-    this software without specific prior written permission.
-  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-  (This is the Modified BSD License)
-*/
+// Copyright 2008-present Contributors to the OpenImageIO project.
+// SPDX-License-Identifier: BSD-3-Clause
+// https://github.com/OpenImageIO/oiio/blob/master/LICENSE.md
 
 // clang-format off
 
@@ -90,23 +64,23 @@ namespace Filesystem {
 
 /// Return the filename (excluding any directories, but including the
 /// file extension, if any) of a filepath.
-OIIO_API std::string filename (const std::string &filepath);
+OIIO_API std::string filename (const std::string &filepath) noexcept;
 
 /// Return the file extension (including the last '.' if
 /// include_dot=true) of a filename or filepath.
 OIIO_API std::string extension (const std::string &filepath,
-                                bool include_dot=true);
+                                bool include_dot=true) noexcept;
 
 /// Return all but the last part of the path, for example,
 /// parent_path("foo/bar") returns "foo", and parent_path("foo")
 /// returns "".
-OIIO_API std::string parent_path (const std::string &filepath);
+OIIO_API std::string parent_path (const std::string &filepath) noexcept;
 
 /// Replace the file extension of a filename or filepath. Does not alter
 /// filepath, just returns a new string.  Note that the new_extension
 /// should contain a leading '.' dot.
 OIIO_API std::string replace_extension (const std::string &filepath, 
-                                        const std::string &new_extension);
+                                        const std::string &new_extension) noexcept;
 
 /// Turn a searchpath (multiple directory paths separated by ':' or ';')
 /// into a vector<string> containing each individual directory.  If
@@ -145,21 +119,21 @@ OIIO_API bool get_directory_entries (const std::string &dirname,
 
 /// Return true if the path is an "absolute" (not relative) path.
 /// If 'dot_is_absolute' is true, consider "./foo" absolute.
-OIIO_API bool path_is_absolute (const std::string &path,
+OIIO_API bool path_is_absolute (string_view path,
                                 bool dot_is_absolute=false);
 
 /// Return true if the file exists.
 ///
-OIIO_API bool exists (const std::string &path);
+OIIO_API bool exists (string_view path) noexcept;
 
 
 /// Return true if the file exists and is a directory.
 ///
-OIIO_API bool is_directory (const std::string &path);
+OIIO_API bool is_directory (string_view path) noexcept;
 
 /// Return true if the file exists and is a regular file.
 ///
-OIIO_API bool is_regular (const std::string &path);
+OIIO_API bool is_regular (string_view path) noexcept;
 
 /// Create the directory. Return true for success, false for failure and
 /// place an error message in err.
@@ -240,6 +214,11 @@ OIIO_API void open (OIIO::ofstream &stream, string_view path,
 /// returning true on success, false on failure.
 OIIO_API bool read_text_file (string_view filename, std::string &str);
 
+/// Write the entire contents of the string `str` to the file, overwriting
+/// any prior contents of the file (if it existed), returning true on
+/// success, false on failure.
+OIIO_API bool write_text_file (string_view filename, string_view str);
+
 /// Read a maximum of n bytes from the named file, starting at position pos
 /// (which defaults to the start of the file), storing results in
 /// buffer[0..n-1]. Return the number of bytes read, which will be n for
@@ -250,15 +229,15 @@ OIIO_API size_t read_bytes (string_view path, void *buffer, size_t n,
 
 /// Get last modified time of file
 ///
-OIIO_API std::time_t last_write_time (const std::string& path);
+OIIO_API std::time_t last_write_time (string_view path) noexcept;
 
 /// Set last modified time on file
 ///
-OIIO_API void last_write_time (const std::string& path, std::time_t time);
+OIIO_API void last_write_time (string_view path, std::time_t time) noexcept;
 
 /// Return the size of the file (in bytes), or uint64_t(-1) if there is any
 /// error.
-OIIO_API uint64_t file_size (string_view path);
+OIIO_API uint64_t file_size (string_view path) noexcept;
 
 /// Ensure command line arguments are UTF-8 everywhere
 ///
@@ -275,7 +254,7 @@ OIIO_API void convert_native_arguments (int argc, const char *argv[]);
 ///                           NOT have been selected by 'x'.
 ///     Note that START may be > FINISH, or STEP may be negative.
 ///  * Multiple values or ranges, separated by a comma (e.g., "3,4,10-20x2")
-/// Retrn true upon success, false if the description was too malformed
+/// Return true upon success, false if the description was too malformed
 /// to generate a sequence.
 OIIO_API bool enumerate_sequence (string_view desc,
                                   std::vector<int> &numbers);
@@ -354,12 +333,12 @@ public:
     virtual bool opened () const { return mode() != Closed; }
     virtual int64_t tell () { return m_pos; }
     virtual bool seek (int64_t offset) { m_pos = offset; return true; }
-    virtual size_t read (void *buf, size_t size) { return 0; }
-    virtual size_t write (const void *buf, size_t size) { return 0; }
+    virtual size_t read (void *buf, size_t size);
+    virtual size_t write (const void *buf, size_t size);
     // pread(), pwrite() are stateless, do not alter the current file
     // position, and are thread-safe (against each other).
-    virtual size_t pread (void *buf, size_t size, int64_t offset) { return 0; }
-    virtual size_t pwrite (const void *buf, size_t size, int64_t offset) { return 0; }
+    virtual size_t pread (void *buf, size_t size, int64_t offset);
+    virtual size_t pwrite (const void *buf, size_t size, int64_t offset);
     virtual size_t size () const { return 0; }
     virtual void flush () const { }
 
@@ -377,7 +356,7 @@ public:
     bool seek (int64_t offset, int origin) {
         return seek ((origin == SEEK_SET ? offset : 0) +
                      (origin == SEEK_CUR ? offset+tell() : 0) +
-                     (origin == SEEK_END ? size() : 0));
+                     (origin == SEEK_END ? offset+int64_t(size()) : 0));
     }
 
 #if OIIO_VERSION >= 20101
